@@ -18,6 +18,8 @@
 use std::collections::{HashMap, HashSet};
 use std::sync::{Arc, Mutex};
 
+use log::{debug, info, warn};
+
 use crate::journal::{
     block_manager::BlockManager, block_validator::BlockStatusStore, block_wrapper::BlockStatus,
     chain::COMMIT_STORE, NULL_BLOCK_IDENTIFIER,
@@ -236,11 +238,11 @@ impl<B: BlockStatusStore> BlockSchedulerState<B> {
     fn update_gauges(&self) {
         gauge!(
             "block_validator.BlockScheduler.blocks_processing",
-            self.processing.len() as i64
+            self.processing.len() as f64
         );
         gauge!(
             "block_validator.BlockScheduler.blocks_pending",
-            self.pending.len() as i64
+            self.pending.len() as f64
         );
     }
 }
