@@ -19,6 +19,7 @@
 use std::convert::TryFrom;
 use std::str::FromStr;
 
+use log::{debug, warn};
 use transact::protocol::{batch::Batch, transaction::Transaction};
 
 use crate::state::settings_view::SettingsView;
@@ -592,7 +593,7 @@ mod tests {
                     .with_family_version("0.test".into())
                     .with_inputs(vec![])
                     .with_outputs(vec![])
-                    .with_payload_hash_method(HashMethod::SHA512)
+                    .with_payload_hash_method(HashMethod::Sha512)
                     .with_payload(vec![])
                     .build(signer)
             })
