@@ -13,21 +13,11 @@
 // limitations under the License.
 
 #[macro_use]
-#[cfg(feature = "diesel")]
+#[cfg(all(feature = "diesel", feature = "transaction-receipt-store"))]
 extern crate diesel;
 #[macro_use]
 #[cfg(feature = "diesel")]
 extern crate diesel_migrations;
-#[cfg(any(
-    feature = "lmdb-store",
-    feature = "validator-internals",
-    feature = "client",
-    feature = "postgres",
-    feature = "sqlite",
-    feature = "lmdb"
-))]
-#[macro_use]
-extern crate log;
 #[cfg(feature = "validator-internals")]
 #[macro_use]
 extern crate metrics;
@@ -52,5 +42,3 @@ pub mod receipt;
 pub mod scheduler;
 #[cfg(feature = "validator-internals")]
 pub mod state;
-#[cfg(feature = "stores")]
-pub mod store;
