@@ -19,6 +19,7 @@
 //! Provides a permission verifier which checks permissions against batch and transaction
 //! signatories.
 
+use log::debug;
 use transact::protocol::{batch::BatchPair, transaction::Transaction};
 
 use crate::protocol::identity::{Permission, Policy};
@@ -443,7 +444,7 @@ mod tests {
                             .with_family_version("1.0".into())
                             .with_inputs(vec![])
                             .with_outputs(vec![])
-                            .with_payload_hash_method(HashMethod::SHA512)
+                            .with_payload_hash_method(HashMethod::Sha512)
                             .with_payload(vec![])
                             .with_nonce(vec![i, j])
                             .build(signer)
