@@ -559,7 +559,7 @@ mod tests {
             .with_family_version("1.0".into())
             .with_inputs(vec![])
             .with_outputs(vec![])
-            .with_payload_hash_method(HashMethod::SHA512)
+            .with_payload_hash_method(HashMethod::Sha512)
             .with_payload(vec![])
             .with_nonce(vec![1])
             .build(signer)
@@ -577,7 +577,7 @@ mod tests {
             .with_family_version("1.0".into())
             .with_inputs(vec![])
             .with_outputs(vec![])
-            .with_payload_hash_method(HashMethod::SHA512)
+            .with_payload_hash_method(HashMethod::Sha512)
             .with_payload(vec![])
             .with_nonce(vec![2])
             .build(signer)
